"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const content_checker_1 = require("@ewizardjs/content-checker");
const commander_1 = require("commander");
const mergeUtils_1 = require("../Api/versionControl/MergeTool/mergeUtils");
const action_1 = require("../Api/versionControl/action");
const I18n_1 = require("../modules/I18n");
const ensureAuth_1 = require("./utils/ensureAuth");
const logger_1 = require("./utils/logger");
const program = new commander_1.Command();
program
    .name('wiz pull')
    .description('wiz pull - Applies the upstream changes to your local project')
    .addOption(new commander_1.Option('--accept <type>', I18n_1.default.info('PULL_ACCEPT_OPTION')).choices(mergeUtils_1.AutoResolve))
    .configureHelp({
    optionDescription: (option) => option.description,
})
    .parse(process.argv);
pull(process.cwd(), program.opts())
    .catch(logger_1.handleError)
    .finally(logger_1.closeLogger);
function pull(baseDir, commandOptions) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, ensureAuth_1.default)();
        yield (0, content_checker_1.validateEwizardContent)(baseDir);
        yield (0, content_checker_1.validateInstalledDependencies)(baseDir);
        return (0, action_1.createVCSAction)(baseDir, { actionType: 'pull' }, commandOptions);
    });
}
//# sourceMappingURL=wiz-pull.js.map