"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const commander = require("commander");
const configureHelpOptions_1 = require("../utils/configureHelpOptions");
const index_1 = require("./../Api/screen/index");
const I18n_1 = require("./../modules/I18n");
const Logger_1 = require("./../modules/Logger");
const utils_1 = require("./../utils");
const ensureAuth_1 = require("./utils/ensureAuth");
const logger_1 = require("./utils/logger");
commander
    .name('wiz screen preview')
    .description('Generate a screenshot for your email preview. To verify the screenshot is up-to-date, run "wiz dev" before "wiz screen preview". Re-run these commands every time you change your project')
    .configureHelp({
    optionDescription: configureHelpOptions_1.capitalizeOptionDescription,
})
    .parse(process.argv);
execute(commander.opts(), process.cwd())
    .catch(logger_1.handleError)
    .finally(logger_1.closeLogger);
function execute(opts, presentationPath) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, ensureAuth_1.default)();
        if (yield (0, utils_1.ensureDevBuild)(presentationPath)) {
            Logger_1.default.info(chalk_1.default.yellow(I18n_1.default.info('SCREEN_PREVIEW_REMINDER')));
        }
        const options = Object.assign(Object.assign({}, opts), { rendererOptions: {
                headless: 'new',
            } });
        const screenAction = yield (0, index_1.createAction)(presentationPath);
        return screenAction(options, presentationPath, 'preview');
    });
}
//# sourceMappingURL=wiz-screen-preview.js.map